using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class TabBox : Control
    {
        private string myTabBorderTemplate, myPageBorderTemplate;
        private List<string> myPages;

        /// <summary>
        /// Template used to draw the border around a tab
        /// </summary>
        [XmlElement("TabBorderTemplate", IsNullable = false)]
        [Browsable(true), Description("The template that defines the art for a tab")]
        public string TabBorderTemplate { get { return myTabBorderTemplate; } set { myTabBorderTemplate = value; } }

        /// <summary>
        /// Template used to draw the border around a page
        /// </summary>
        [XmlElement("PageBorderTemplate", IsNullable = false)]
        [Browsable(true), Description("The template that defines the art for the main window frame where each tab page goes.")]
        public string PageBorderTemplate { get { return myPageBorderTemplate; } set { myPageBorderTemplate = value; } }

        /// <summary>
        /// Collection of pages in this TabBox
        /// </summary>
        [XmlElement("Pages", IsNullable = false)]
        [Browsable(true), Description("A collection of pages (each page gets an associated tab).")]
        public List<string> Pages { get { return myPages; } set { myPages = value; } }

        public TabBox() : this(null) { }
        public TabBox(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            TabBox temp_TabBox = obj as TabBox;
            if (temp_TabBox != null)
            {
                TabBorderTemplate = temp_TabBox.TabBorderTemplate;
                PageBorderTemplate = temp_TabBox.PageBorderTemplate;
                Pages = temp_TabBox.Pages;
            }
        }
    }
}
